import type { FixtureTypeTree, FixtureTypeVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  fixtureTypeExport = '/eims/fixtureType/export',
  fixtureTypeList = '/eims/fixtureType/list',
  fixtureTypeTree = '/eims/fixtureType/tree',
  root = '/eims/fixtureType'
}

/**
 * 查询工具类型列表
 * @param query
 * @returns {*}
 */

export function listFixtureType(params?: any) {
  return requestClient.get<FixtureTypeVO[]>(Api.fixtureTypeList, { params });
}

/**
 * 获取工具类型树
 * @returns 工具树数组
 */
export function getFixtureTypeTree() {
  return requestClient.get<FixtureTypeTree[]>(Api.fixtureTypeTree);
}

/**
 * 查询工具类型详细
 * @param fixTypeId
 */
export function getFixtureType(fixTypeId: ID) {
  return requestClient.get<FixtureTypeVO>(`${Api.root}/${fixTypeId}`);
}

/**
 * 新增工具类型
 * @param data
 */
export function addFixtureType(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}
/**
 * 修改工具类型
 * @param data
 */
export function updateFixtureType(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除工具类型
 * @param fixTypeId
 */
export function delFixtureType(fixTypeId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${fixTypeId}`);
}
/**
 * 导出
 * @param
 */
export function fixtureTypeExport(data: any) {
  return commonExport(Api.fixtureTypeExport, data);
}
